@@ -112,37 +112,6 @@ download_from_url <- function(url,
   return(path)
 }
 
-#' Checks UTF-8-BOM encoding.
-#' 
-#' Special thanks to @patperu for finding the issue and 
-#' to @hrbrmstr for the code to help deal with the issue.
-#' 
-#' @param path the path the the text file
-#' @param encoding can be one of \code{UTF-8}, \code{UTF-16} or \code{UTF-16BE}.
-#'        Although a BOM could be used with UTF-32 and other encodings, such
-#'        encodings are rarely used for data transmission and the three supported
-#'        encodings are the most likely ones folks in R will be working with from
-#'        web APIs.\cr\cr
-#'        This function defaults to looking for \code{UTF-8} BOM, but you can
-#'        override it.
-#' @return \code{TRUE} if response contains a BOM, \code{NA} if an unsupported encoding
-#'         was passed (along with a message)
-#' @references \href{http://www.unicode.org/faq/utf_bom.html}{UTF-8, UTF-16, UTF-32 & BOM}
-#' @noRd
-#' @keywords internal
-#' @author @@hrbrmstr
-
-has_bom <- function(path, encoding="UTF-8") {
-
-  B <- readBin(path, "raw", 4, 1)
-  switch(encoding,
-       `UTF-8`=B[1]==as.raw(0xef) & B[2]==as.raw(0xbb) & B[3]==as.raw(0xbf),
-       `UTF-16`=B[1]==as.raw(0xff) & B[2]==as.raw(0xfe),
-       `UTF-16BE`=B[1]==as.raw(0xfe) & B[2]==as.raw(0xff),
-       { message("Unsupported encoding") ; return(NA) }
-  )
-}
-
 #' Unzip a file and delete zip
 #'
 #' @param zipfile path to zipped file
@@ -354,59 +323,19 @@ parse_gtfs_file <- function(prefix, file_path, quiet = FALSE) {
         "D" = readr::col_date(format = "%Y%m%d")
       )
     
-    if (has_bom(file_path)) { # check for BOM. if yes, use read.csv()
-      ## switch function
-      converttype <- function(x, y) {
-        switch(x, 
-               character = as.character(y), 
-               integer = as.integer(y), 
-               double = as.double(y), 
-               Date = lubridate::ymd(y))
-      }
-      #get expected/required names for columns. 
-      #these are imposed.
-      colnms <- meta$field[indx] 
-      ## get colclasses
-      colclasses <- sapply(coltypes_character, 
-                           switch, 
-                           c = "character", 
-                           i = "integer", 
-                           d = "double", 
-                           "D" = "Date")
-      
-      csv <- quote(utils::read.csv(file_path, 
-                                   col.names = colnms, 
-                                   stringsAsFactors= FALSE))
-      df <- try(suppressWarnings(eval(csv)) %>%
-              mapply(converttype,
-                     # ensure proper column types
-                     x = colclasses,
-                     y = ., SIMPLIFY = FALSE) %>% 
-              tibble::as_tibble())
-
-      if(any(class(df) %in% "try-error")) {
-        probs <- "Error during import. 
-                  Likely encoding error. 
-                  Note that utils::read.csv() 
-                  was used, not readr::read_csv()."
-        attributes(df) <- append(attributes(df), list(problems = probs))
-      }
-    } else {
-      df <- suppressWarnings(
-        readr::read_csv(file = file_path, 
-          col_types = coltypes
-        )
+    df <- suppressWarnings(
+      readr::read_csv(file = file_path, 
+                      col_types = coltypes
       )
-      probs <- readr::problems(df)
-      
-      if(dim(probs)[1] > 0) {
-        attributes(df) <- append(attributes(df), list(problems = probs))
-        warning(paste0("Parsing failures while reading ", prefix))
-        print(probs)
-      }
+    )
+    probs <- readr::problems(df)
+    
+    if(dim(probs)[1] > 0) {
+      attributes(df) <- append(attributes(df), list(problems = probs))
+      warning(paste0("Parsing failures while reading ", prefix))
+      print(probs)
     }
-
+    
     return(df)
   } else return(NULL)
-
 }
