@@ -102,37 +102,4 @@ planner_buffer <- function(df_sf1,dist="h",crs=26910) {
   df2 <- sf::st_transform(df_sf1,crs)
   df3 <- sf::st_buffer(df2,dist=distance)
   return(df3)
-}
-
-#' This function is deprecated. Please use get_stop_geometry
-#' Make Stops into Simple Features Points
-#'
-#' @param stops a gtfs$stops dataframe
-#' @export
-#' @return an sf dataframe for gtfs routes with a point column
-#' @examples
-#' data(gtfs_obj)
-#' some_stops <- gtfs_obj$stops[sample(nrow(gtfs_obj$stops), 40),]
-#' some_stops_sf <- get_stop_geometry(some_stops)
-#' plot(some_stops_sf)
-stops_df_as_sf <- function(stops) {
-  .Deprecated("get_stop_geometry", package="tidytransit")
-  get_stop_geometry(stops)
-}
-
-#' This function is deprecated. Please use get_route_geometry
-#' Make Routes into Simple Features Lines
-#'
-#' @param gtfs_obj gtfs object
-#' @param route_ids select routes to convert to simple features
-#' @param service_ids select service_ids to convert to simple features
-#' @export
-#' @return an sf dataframe for gtfs routes with a multilinestring column
-#' @examples
-#' data(gtfs_obj)
-#' routes_sf <- get_route_geometry(gtfs_obj)
-#' plot(routes_sf[1,])
-routes_df_as_sf <- function(gtfs_obj, route_ids = NULL, service_ids = NULL) {
-  .Deprecated("get_route_geometry", package="tidytransit")
-  get_route_geometry(gtfs_obj, route_ids = NULL, service_ids = NULL)
-}
+}
\ No newline at end of file
